@@ -1,9 +1,17 @@
 package App::Ack::Filter;
 
+=head1 NAME
+
+App::Ack::Filter
+
+=head1 DESCRIPTION
+
+An abstract superclass that represents objects that can filter `App::Ack::Resource` objects.
+
+=cut
+
 use strict;
 use warnings;
-use overload
-    '""' => 'to_string';
 
 use App::Ack::Filter::Inverse ();
 use Carp 1.04 ();
@@ -78,7 +86,8 @@ sub register_filter {
 =head2 $filter->filter($resource)
 
 Must be implemented by filter implementations.  Returns
-true if the filter passes, false otherwise.
+true if the filter passes, false otherwise.  This method
+must B<not> alter the passed-in C<$resource> object.
 
 =head2 $filter->invert()
 
