@@ -4,18 +4,23 @@ use strict;
 use warnings;
 use base 'Exporter';
 
-use App::Ack::Resource::Basic;
-use File::Find;
+use App::Ack::Resource;
+use File::Next;
 use Util;
 use Test::More;
 
 our @EXPORT = qw(filter_test);
 
-my @swamp_files;
+sub swamp_files {
+    my @swamp_files;
 
-find(sub {
-    push @swamp_files, $File::Find::name if -f;
-}, 't/swamp');
+    my $files = File::Next::files( 't/swamp' );
+    while ( my $file = $files->() ) {
+        push( @swamp_files, $file );
+    }
+
+    return @swamp_files;
+}
 
 sub filter_test {
     local $Test::Builder::Level = $Test::Builder::Level + 1;
@@ -36,8 +41,8 @@ sub filter_test {
         } grep {
             $filter->filter($_)
         } map {
-            App::Ack::Resource::Basic->new($_)
-        } @swamp_files;
+            App::Ack::Resource->new($_)
+        } swamp_files();
 
         sets_match(\@matches, $expected_matches, $msg);
     };
